.. _orca_inventory:

orca
==============

.. note::
    Currently, only the ``linear`` and ``nearest-neighbour`` interpolation methods are supported for ORCA grids.

.. module-output:: generate_inventory_rst orca "ORCA"
